You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2018/03/06 17:39:55 UTC

[1/3] activemq-artemis git commit: This closes #1934

Repository: activemq-artemis
Updated Branches:
  refs/heads/master e82b08584 -> 315c1e4c5


This closes #1934


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/315c1e4c
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/315c1e4c
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/315c1e4c

Branch: refs/heads/master
Commit: 315c1e4c555c9d3f14f805c75495dc495d291717
Parents: e82b085 e999183
Author: Clebert Suconic <cl...@apache.org>
Authored: Tue Mar 6 12:39:43 2018 -0500
Committer: Clebert Suconic <cl...@apache.org>
Committed: Tue Mar 6 12:39:43 2018 -0500

----------------------------------------------------------------------
 .../artemis/core/server/impl/TransientQueueManagerImpl.java     | 3 +++
 .../activemq/artemis/jms/example/KillSlowConsumerExample.java   | 5 ++---
 .../activemq/artemis/jms/example/NotifySlowConsumerExample.java | 2 --
 .../src/main/resources/activemq/server0/broker.xml              | 4 ++--
 4 files changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------



[2/3] activemq-artemis git commit: NO-JIRA Adjust slow consumer example timing

Posted by cl...@apache.org.
NO-JIRA Adjust slow consumer example timing


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/e9991838
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/e9991838
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/e9991838

Branch: refs/heads/master
Commit: e9991838c88a62dd5e567d633bddea7fe89c99d4
Parents: b638748
Author: Justin Bertram <jb...@apache.org>
Authored: Tue Mar 6 11:31:25 2018 -0600
Committer: Clebert Suconic <cl...@apache.org>
Committed: Tue Mar 6 12:39:43 2018 -0500

----------------------------------------------------------------------
 .../activemq/artemis/jms/example/KillSlowConsumerExample.java   | 5 ++---
 .../activemq/artemis/jms/example/NotifySlowConsumerExample.java | 2 --
 .../src/main/resources/activemq/server0/broker.xml              | 4 ++--
 3 files changed, 4 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/e9991838/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/KillSlowConsumerExample.java
----------------------------------------------------------------------
diff --git a/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/NotifySlowConsumerExample.java b/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/NotifySlowConsumerExample.java
index cc713a7..22c2ba9 100644
--- a/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/NotifySlowConsumerExample.java
+++ b/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/NotifySlowConsumerExample.java
@@ -103,8 +103,6 @@ public class NotifySlowConsumerExample {
          if (!isNotified) {
             throw new RuntimeException("SlowConsumerExample.demoSlowConsumerNotify() FAILED; timeout occurred before" + " - slow consumer notification was received. ");
          }
-
       }
-
    }
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/e9991838/examples/features/standard/slow-consumer/src/main/resources/activemq/server0/broker.xml
----------------------------------------------------------------------
diff --git a/examples/features/standard/slow-consumer/src/main/resources/activemq/server0/broker.xml b/examples/features/standard/slow-consumer/src/main/resources/activemq/server0/broker.xml
index c8c927a..ec8797c 100644
--- a/examples/features/standard/slow-consumer/src/main/resources/activemq/server0/broker.xml
+++ b/examples/features/standard/slow-consumer/src/main/resources/activemq/server0/broker.xml
@@ -52,13 +52,13 @@ under the License.
          <address-setting match="slow.consumer.kill">
             <slow-consumer-threshold>10</slow-consumer-threshold>
             <slow-consumer-policy>KILL</slow-consumer-policy>
-            <slow-consumer-check-period>5</slow-consumer-check-period>
+            <slow-consumer-check-period>3</slow-consumer-check-period>
          </address-setting>
 
          <address-setting match="slow.consumer.notify">
             <slow-consumer-threshold>10</slow-consumer-threshold>
             <slow-consumer-policy>NOTIFY</slow-consumer-policy>
-            <slow-consumer-check-period>5</slow-consumer-check-period>
+            <slow-consumer-check-period>3</slow-consumer-check-period>
          </address-setting>
       </address-settings>
 


[3/3] activemq-artemis git commit: NO-JIRA ignore exception when deleting temp queue

Posted by cl...@apache.org.
NO-JIRA ignore exception when deleting temp queue


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/b638748a
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/b638748a
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/b638748a

Branch: refs/heads/master
Commit: b638748ae366d613b1635a89df71c911ea704e61
Parents: e82b085
Author: Justin Bertram <jb...@apache.org>
Authored: Tue Mar 6 11:29:24 2018 -0600
Committer: Clebert Suconic <cl...@apache.org>
Committed: Tue Mar 6 12:39:43 2018 -0500

----------------------------------------------------------------------
 .../artemis/core/server/impl/TransientQueueManagerImpl.java       | 3 +++
 1 file changed, 3 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/b638748a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/TransientQueueManagerImpl.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/TransientQueueManagerImpl.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/TransientQueueManagerImpl.java
index ab14479..4985a7e 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/TransientQueueManagerImpl.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/TransientQueueManagerImpl.java
@@ -17,6 +17,7 @@
 package org.apache.activemq.artemis.core.server.impl;
 
 import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.ActiveMQNonExistentQueueException;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.server.ActiveMQServerLogger;
@@ -40,6 +41,8 @@ public class TransientQueueManagerImpl extends ReferenceCounterUtil implements T
 
          try {
             server.destroyQueue(queueName, null, false);
+         } catch (ActiveMQNonExistentQueueException e) {
+            // ignore
          } catch (ActiveMQException e) {
             ActiveMQServerLogger.LOGGER.errorOnDeletingQueue(queueName.toString(), e);
          }
diff --git a/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/KillSlowConsumerExample.java b/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/KillSlowConsumerExample.java
index 3b0f683..867b87d 100644
--- a/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/KillSlowConsumerExample.java
+++ b/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/KillSlowConsumerExample.java
@@ -34,12 +34,12 @@ import org.apache.activemq.artemis.api.core.ActiveMQObjectClosedException;
  *
  * - sends messages to a queue "slow.consumer.kill".
  * - starts a consumer BUT does not consume any messages.
  * - waits for 8 seconds and tries to consume a message.
  * - receive an exception as the connection should already be closed.
  */
 public class KillSlowConsumerExample {
 
-   public static final int WAIT_TIME = 7;
+   public static final int WAIT_TIME = 10;
 
    public static void main(final String[] args) throws Exception {
 
@@ -98,7 +98,6 @@ public class KillSlowConsumerExample {
             }
          }
       }
-
    }
 }
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/e9991838/examples/features/standard/slow-consumer/src/main/java/org/apache/activemq/artemis/jms/example/NotifySlowConsumerExample.java
----------------------------------------------------------------------
@@ -34,12 +34,12 @@ import org.apache.activemq.artemis.api.core.ActiveMQObjectClosedException;
  * - sends messages to a queue "slow.consumer.kill".
  * - starts a consumer BUT does not consume any messages.
- * - waits for 8 seconds and tries to consume a message.
+ * - waits for 10 seconds and tries to consume a message.
  * - receive an exception as the connection should already be closed.
  */